==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/language/1/barnraiser_01/pol_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_options'] = 							"options";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_poll'] = 							"poll";
$lang['hdr_poll_usage'] = 						"poll usage";
$lang['hdr_vote_history'] =						"vote history";
$lang['section_publishing'] = 					"publishing";


//HREF
$lang['href_add'] = 							"add";
$lang['href_list'] = 							"list";


//SUBMIT BUTTONS
$lang['sub_add'] = 								"add";
$lang['sub_update'] = 							"update";
$lang['sub_edit'] = 							"edit";


// FORMS
$lang['form_label_start_date'] = 				"From date";
$lang['form_label_end_date'] = 					"To date";
$lang['form_label_start_time'] = 				"From time";
$lang['form_label_end_time'] = 					"To time";
$lang['form_rsp_group'] = 						"Check to submit this to the web site editor for inclusion on the group home page.";
$lang['form_rsp_node'] = 						"Check to submit this to the node editor for inclusion in Splash.";
$lang['form_rsp_group_auto'] = 					"Check to add this to the group home page.";
$lang['form_rsp_node_auto'] = 					"Check to add this to Splash.";
$lang['form_submit_save_go'] = 					"SAVE AND GO";
$lang['form_submit_save'] = 					"SAVE";
$lang['form_just_me'] = 						"just me";


//BODY TEXT
$lang['txt_end'] = 								"end";
$lang['txt_add_poll_option'] =					"add a poll option";
$lang['txt_anonymous'] =						"anonymous";
$lang['txt_anonymous_help'] =					"most polls should not be anonymous, however on sensitive issues you may wish to hide the identification of the participant.";
$lang['txt_start'] = 							"start";
$lang['txt_question'] =							"question";
$lang['txt_required'] =							"required";
$lang['txt_required_help'] =					"Is the participant required to vote prior to reading the comments?";
$lang['txt_poll_intro'] =						"Fill in this form to add a Poll. After you add it you will be prompted to create answer options. Please ensure that your question and options are clear to ensure clarity in the vote.<br /><br />You can edit or delete your poll providing that it has received no votes or comments. The poll will only be visible after the start date and time. Votes and comments can only be received after that time and before the end date and time.";
$lang['txt_poll_intro'] = 						"You can add a poll to this community. A poll is question for the community with optional answers. People vote by selecting the answer they agree with the most.";
$lang['txt_publish_level'] =					"everyone";
$lang['txt_publish_node_help'] =				"Item will be submitted to Splash editor and can be viewed by any member of this community.";
$lang['txt_publish_public_help'] =				"Item will be submitted to web site editor and can be viewed by anyone.";
$lang['txt_publish_help'] =						"How wide do you want the audience of your event to be? You can publish to just your friends, wider degrees of acquaintances or the Splash magazine page.";
$lang['txt_none'] = 							"none";
$lang['txt_header_1'] = 						"1. Poll overview";
$lang['txt_overview_intro'] =					"Please ensure that your question and options are clear to ensure clarity in the vote. You can edit or delete your poll providing that it has received no votes or comments. The poll will only be visible after the start date and time. Votes and comments can only be received after that time and before the end date and time.";
$lang['txt_header_2'] = 						"2. Date and time";
$lang['txt_date_intro'] = 						"Enter a start and end date and time for your poll. You can use the popup calendar to enter a date and time or just type on in. The format is important. Please type the date as yyyy-dd-mm and the time as hh:mm.";
$lang['txt_header_3'] = 						"3. Options";
$lang['txt_option_intro'] = 					"You can enter as many options as you like, however less than 6 options are recommended for easy reading.";
$lang['txt_header_4'] =							"edit or delete a poll option";
$lang['txt_poll_option_intro'] =				"Remember to give neutral or unbias questions and options if you want to create a accurate Poll.";
$lang['txt_header_5'] = 						"5. Publishing";
$lang['txt_publishing_intro'] = 				"Choose where you would like this poll to be published to.";
$lang['txt_header_6'] = 						"6. Save";
$lang['txt_save_intro'] = 						"Save your work. 'save and go' will take you to the details page.";
$lang['txt_not_saved'] = 						"Please save your work first.";

?>

==> aroundme_0_6_0.zip: aroundme_0_6_0/aroundme/language/1/barnraiser_01/pol_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'frm_view.lang.php');

//HEADER
$lang['hdr_options'] = 							"options";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_poll'] = 							"poll";
$lang['hdr_poll_usage'] = 						"poll usage";
$lang['hdr_vote_history'] =						"vote history";
$lang['hdr_publishing'] = 						"publishing";
$lang['hdr_group_poll'] = 						"group poll";


//HREF
$lang['href_add'] = 							"add";
$lang['href_list'] = 							"list";


// FORMS
$lang['form_label_start_date'] = 				"From date";
$lang['form_label_end_date'] = 					"To date";
$lang['form_label_start_time'] = 				"From time";
$lang['form_label_end_time'] = 					"To time";
$lang['form_label_comments'] = 					"Allow comments";
$lang['form_just_me'] = 						"just me";
$lang['form_label_preview'] = 					"preview";
$lang['form_body'] = 							"details";
$lang['form_rsp_group'] = 						"Submit to group home page editor";
$lang['form_rsp_node'] = 						"Check to submit this to the node editor for inclusion in the 'stuff' section";
$lang['form_rsp_group_auto'] = 					"Add to group home page";
$lang['form_rsp_node_auto'] = 					"Add to 'stuff' section";


//BODY TEXT
$lang['txt_end'] = 								"end";
$lang['txt_add_poll_option'] =					"add a poll option";
$lang['txt_anonymous'] =						"anonymous";
$lang['txt_anonymous_help'] =					"most polls should not be anonymous, however on sensitive issues you may wish to hide the identification of the participant.";
$lang['txt_start'] = 							"start";
$lang['txt_question'] =							"question";
$lang['txt_required'] =							"required";
$lang['txt_required_help'] =					"Is the participant required to vote prior to reading the comments?";
$lang['txt_poll_intro'] =						"Fill in this form to add a Poll. After you add it you will be prompted to create answer options. Please ensure that your question and options are clear to ensure clarity in the vote.<br /><br />You can edit or delete your poll providing that it has received no votes or comments. The poll will only be visible after the start date and time. Votes and comments can only be received after that time and before the end date and time.";
$lang['txt_poll_intro'] = 						"You can add a poll to this community. A poll is question for the community with optional answers. People vote by selecting the answer they agree with the most.";
$lang['txt_publish_help'] =						"How wide do you want the audience of your event to be? You can publish to just your friends, wider degrees of acquaintances or the Splash magazine page.";
$lang['txt_none'] = 							"none";
$lang['txt_header_1'] = 						"1. Poll overview";
$lang['txt_overview_intro'] =					"Please ensure that your question and options are clear to ensure clarity in the vote. You can edit or delete your poll providing that it has received no votes or comments. The poll will only be visible after the start date and time. Votes and comments can only be received after that time and before the end date and time.";
$lang['txt_header_2'] = 						"2. Date and time";
$lang['txt_date_intro'] = 						"Enter a start and end date and time for your poll. You can use the popup calendar to enter a date and time or just type on in. The format is important. Please type the date as yyyy-dd-mm and the time as hh:mm.";
$lang['txt_header_3'] = 						"3. Options";
$lang['txt_option_intro'] = 					"You can enter as many options as you like, however less than 6 options are recommended for easy reading.";
$lang['txt_header_4'] =							"edit or delete a poll option";
$lang['txt_poll_option_intro'] =				"Remember to give neutral or unbias questions and options if you want to create a accurate Poll.";
$lang['txt_header_5'] = 						"4. Publishing";
$lang['txt_publishing_intro'] = 				"Choose where you would like this poll to be published to.";
$lang['txt_header_6'] = 						"5. Save";
$lang['txt_save_intro'] = 						"Save your work. 'save and go' will take you to the details page.";
$lang['txt_not_saved'] = 						"Please save your work first.";
$lang['txt_header_7'] = 						"5. Details";
$lang['txt_detail_intro'] = 					"You can optionally add detailed text which will appear under the question.";
$lang['sub_check_spelling'] = 					"check spelling";

$lang['txt_publish_node_help'] =				"Submit to 'Stuff' editor";
$lang['txt_publish_auto_node_help'] = 			"Stuff";

$lang['txt_publish_public_help'] =				"Submit to public web site editor";
$lang['txt_publish_auto_public_help'] =			"public web site";

?>
